@@ -10,9 +10,9 @@ use Rose::HTML::Form::Field::Group;
 use Rose::HTML::Form::Field::Group::OnOff;
 our @ISA = qw(Rose::HTML::Form::Field::Group::OnOff);
 
-our $VERSION = '0.551';
+our $VERSION = '0.554';
 
-sub _item_class       { 'Rose::HTML::Form::Field::Checkbox' }
+sub _item_class       { shift->object_type_class('checkbox') }
 sub _item_name        { 'checkbox' }
 sub _item_name_plural { 'checkboxes' }
 
@@ -34,6 +34,9 @@ sub _item_name_plural { 'checkboxes' }
 *delete_checkbox_group    = \&Rose::HTML::Form::Field::Group::delete_item_group;
 *delete_checkboxes_groups = \&Rose::HTML::Form::Field::Group::delete_item_groups;
 
+*checkboxes_html_attr        = \&Rose::HTML::Form::Field::Group::items_html_attr;
+*delete_checkboxes_html_attr = \&Rose::HTML::Form::Field::Group::delete_items_html_attr;
+
 sub html_table
 {
   my($self, %args) = @_;
@@ -116,6 +119,12 @@ L<Rose::HTML::Form::Field::CheckboxGroup> is an object wrapper for a group of ch
 
 This class inherits from, and follows the conventions of, L<Rose::HTML::Form::Field>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::HTML::Form::Field> documentation for more information.
 
+=head1 HIERARCHY
+
+A checkbox group is an abstraction with no corresponding parent HTML element; the individual L<checkbox|Rose::HTML::Form::Field::Checkbox> objects in the group exist as siblings.  As such, the list of L<child|Rose::HTML::Object/HIERARCHY> objects will always be empty and cannot be modified.  To get the list of siblings, use the L<checkboxes|/checkboxes> method.
+
+See the "hierarchy" sections of the L<Rose::HTML::Form::Field/HIERARCHY> and L<Rose::HTML::Form/HIERARCHY> documentation for an overview of the relationship between field and form objects and the child-related methods inherited from L<Rose::HTML::Object>.
+
 =head1 HTML ATTRIBUTES
 
 None.  This class is simply an aggregator of L<Rose::HTML::Form::Field::Checkbox> objects.
@@ -250,6 +259,10 @@ This is an alias for the L<checkboxes|/checkboxes> method.
 
 Get or set the default number of columns to use in the output of the L<html_table()|/html_table> and L<xhtml_table()|/xhtml_table> methods.
 
+=item B<checkboxes_html_attr NAME [, VALUE]>
+
+If VALUE is passed, set the L<HTML attribute|Rose::HTML::Object/html_attr> named NAME on all L<checkboxes|/checkboxes>.  Otherwise, return the value of the  L<HTML attribute|Rose::HTML::Object/html_attr> named NAME on the first checkbox encountered in the list of all L<checkboxes|/checkboxes>.
+
 =item B<delete_checkbox VALUE>
 
 Deletes the first checkbox (according to the order that they are returned from L<checkboxes()|/checkboxes>) whose "value" HTML attribute is VALUE.  Returns the deleted checkbox or undef if no such checkbox exists.
@@ -260,6 +273,14 @@ Repeatedly calls L<delete_checkbox|/delete_checkbox>, passing each value in LIST
 
 Deletes the first checkbox (according to the order that they are returned from L<checkboxes()|/checkboxes>) whose "value" HTML attribute is VALUE, or undef if no such checkbox exists.
 
+=item B<delete_checkboxes_html_attr NAME>
+
+Delete the L<HTML attribute|Rose::HTML::Object/html_attr> named NAME from each L<checkbox|/checkboxes>.
+
+=item B<delete_items_html_attr NAME>
+
+This is an alias for the L<delete_checkboxes_html_attr|/delete_checkboxes_html_attr> method.
+
 =item B<has_value VALUE>
 
 Returns true if the checkbox whose value is VALUE is checked, false otherwise.
@@ -314,6 +335,10 @@ A reference to a hash of HTML attribute/value pairs to be used in the "tr" tag,
 
 Specifying "rows" and "columns" values (either as ARGS or via L<rows()|/rows> and L<columns()|/columns>) that are both greater than 1 leads to undefined behavior if there are not exactly "rows x columns" checkboxes.  For predictable behavior, set either rows or columns to a value greater than 1, but not both.
 
+=item B<items_html_attr NAME [, VALUE]>
+
+This is an alias for the L<checkboxes_html_attr|/checkboxes_html_attr> method.
+
 =item B<label VALUE [, LABEL]>
 
 Get or set the label for the checkbox whose value is VALUE.  The label for that checkbox is returned. If the checkbox exists, but has no label, then the value itself is returned. If the checkbox does not exist, then undef is returned.
