@@ -13,7 +13,7 @@ use Rose::HTML::Util();
 use Rose::HTML::Form::Field;
 our @ISA = qw(Rose::HTML::Form::Field);
 
-our $VERSION = '0.551';
+our $VERSION = '0.554';
 
 our $Debug = undef;
 
@@ -54,10 +54,12 @@ sub _item_name_plural { 'items' }
 
 sub children 
 {
-  Carp::croak "children() does not take any arguments"  if(@_ > 1);
-  return shift->items();
+  Carp::croak "Cannot set children() for a pseudo-group ($_[0])"  if(@_ > 1);
+  return wantarray ? () : [];
 }
 
+sub is_flat_group { 1 }
+
 sub items
 {
   my($self) = shift;
@@ -126,6 +128,52 @@ sub delete_item
   return splice(@$items, $i, 1);
 }
 
+sub push_items { shift->add_items(@_) }
+sub push_item  { shift->add_item(@_) }
+
+sub pop_items
+{
+  my($self) = shift;
+
+  my $items = $self->items || [];
+
+  if(@_)
+  {
+    my $offset = $#$items - $_[0];
+    return splice(@$items, $offset < 0 ? 0 : $offset)  
+  }
+
+  my @items = pop(@$items);
+  $self->init_items  if(@items);
+  return @items;
+}
+
+sub pop_item { shift->pop_items(@_) }
+
+sub shift_items
+{
+  my($self) = shift;
+
+  my $items = $self->items || [];
+
+  my @items = @_ ? splice(@$items, 0, $_[0]) : shift(@$items);
+  $self->init_items  if(@items);
+  return @items;
+}
+
+sub shift_item { shift->shift_items(@_) }
+
+sub unshift_items
+{
+  my($self) = shift;
+
+  unshift(@{$self->{'items'}}, $self->_args_to_items({ localized => 0 }, @_));
+
+  $self->init_items;
+}
+
+sub unshift_item { shift->unshift_items(@_) }
+
 sub delete_items
 {
   my($self) = shift;
@@ -188,6 +236,38 @@ sub items_localized
   return (wantarray) ? @{$self->{'items'}} : $self->{'items'};
 }
 
+sub items_html_attr
+{
+  my($self, $name) = (shift, shift);
+
+  if(@_)
+  {
+    foreach my $item ($self->items)
+    {
+      $item->html_attr($name, @_);
+    }
+
+    return @_;
+  }
+
+  foreach my $item (@{[ $self->items ]})
+  {
+    return $item->html_attr($name);
+  }
+
+  return undef;
+}
+
+sub delete_items_html_attr
+{
+  my($self) = shift;
+
+  foreach my $item ($self->items)
+  {
+    $item->delete_html_attr(@_);
+  }
+}
+
 *fields           = \&items;
 *fields_localized = \&items_localized;
 
@@ -590,6 +670,25 @@ sub xhtml_field
 
 *xhtml_fields = \&xhtml_field;
 
+sub escape_html
+{
+  my($self) = shift;
+
+  if(@_)
+  {
+    my $val = $self->SUPER::escape_html(@_);
+
+    foreach my $item ($self->items)
+    {
+      $item->escape_html($val);
+    }
+
+    return $val;
+  }
+
+  return $self->SUPER::escape_html(@_);
+}
+
 sub hidden_fields
 {
   my($self) = shift;
@@ -604,20 +703,6 @@ sub hidden_fields
   return (wantarray) ? @hidden : \@hidden;
 }
 
-sub escape_html
-{
-  my($self) = shift;
-
-  return $self->{'escape_html'}  unless(@_);
-
-  foreach my $field ($self->fields)
-  {
-    $field->escape_html(@_);
-  }
-
-  return $self->{'escape_html'} = shift;
-}
-
 # XXX: Could someday use Rose::HTML::Table::*
 
 sub html_table
