@@ -7,7 +7,7 @@ use Rose::HTML::Object::Errors qw(:phone);
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.541';
+our $VERSION = '0.549';
 
 __PACKAGE__->add_required_html_attrs(
 {
@@ -70,6 +70,10 @@ PHONE_INVALID = "Die Telefon-Nummer muß 10 Stellen enthalten (einschließlich V
 
 PHONE_INVALID = "Le numéro de téléphone, indicatif compris, doit avoir 10 chiffres."
 
+[% LOCALE bg %]
+
+PHONE_INVALID = "Телефонния номер (вкл. кода на областта) не трябва да надвишава 10 цифри."
+
 __END__
 
 =head1 NAME
@@ -104,8 +108,8 @@ This is a good example of a custom field class that constrains the kinds of inpu
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
