@@ -7,7 +7,7 @@ use Carp();
 use Rose::HTML::Form::Field::Input;
 our @ISA = qw(Rose::HTML::Form::Field::Input);
 
-use Rose::HTML::Object::MakeMethods
+use Rose::HTML::Object::MakeMethods::Localization
 (
   localized_message =>
   [
@@ -21,7 +21,10 @@ __PACKAGE__->add_required_html_attrs(
   name  => '',
 });
 
-our $VERSION = '0.011';
+our $VERSION = '0.554';
+
+sub is_button { 1 }
+sub is_empty { 1 }
 
 sub hidden_fields      { (wantarray) ? () : [] }
 sub html_hidden_fields { (wantarray) ? () : [] }
@@ -212,6 +215,10 @@ The "src" HTML attribute must be set (either in ARGS or from an existing value f
 
 Like L<image_html()|/image_html>, but serialized to XHTML instead.
 
+=item B<is_empty>
+
+Returns true.
+
 =item B<value [VALUE]>
 
 Gets or sets the value of the "value" HTML attribute.
