@@ -2,27 +2,168 @@ package Rose::HTML::Object;
 
 use strict;
 
+use base 'Rose::HTML::Object::Localized';
+
 use Carp;
+use Scalar::Util();
 
 use Rose::HTML::Util();
 use Rose::HTML::Object::Message::Localizer;
 
-use Rose::HTML::Object::Localized;
-our @ISA = qw(Rose::HTML::Object::Localized);
-
-our $VERSION = '0.550';
+our $VERSION = '0.554';
 
 our $Debug = undef;
 
+#
+# Class data
+#
+
+use Rose::Class::MakeMethods::Generic
+(
+  inherited_hash =>
+  [
+    'object_type_class' => { plural_name => 'object_type_classes' },
+  ],
+);
+
+__PACKAGE__->localizer(Rose::HTML::Object::Message::Localizer->new);
+
+__PACKAGE__->autoload_html_attr_methods(1);
+
+__PACKAGE__->add_valid_html_attrs
+(
+  'id',
+  'class',
+  'style',
+  'title',
+  'lang',
+  'xml:lang',
+  'dir',
+  'onclick',
+  'ondblclick',
+  'onmousedown',
+  'onmouseup',
+  'onmouseover',
+  'onmousemove',
+  'onmouseout',
+  'onkeypress',
+  'onkeydown',
+  'onkeyup'
+);
+
+__PACKAGE__->object_type_classes
+(
+  'form'               => 'Rose::HTML::Form',
+  'repeatable form'    => 'Rose::HTML::Form::Repeatable',
+
+  #'repeatable field'   => 'Rose::HTML::Form::Field::Repeatable',
+
+  'text'               => 'Rose::HTML::Form::Field::Text',
+  'scalar'             => 'Rose::HTML::Form::Field::Text',
+  'char'               => 'Rose::HTML::Form::Field::Text',
+  'character'          => 'Rose::HTML::Form::Field::Text',
+  'varchar'            => 'Rose::HTML::Form::Field::Text',
+  'string'             => 'Rose::HTML::Form::Field::Text',
+
+  'text area'          => 'Rose::HTML::Form::Field::TextArea',
+  'textarea'           => 'Rose::HTML::Form::Field::TextArea',
+  'blob'               => 'Rose::HTML::Form::Field::TextArea',
+
+  'option'             => 'Rose::HTML::Form::Field::Option',
+  'option group'       => 'Rose::HTML::Form::Field::OptionGroup',
+
+  'checkbox'           => 'Rose::HTML::Form::Field::Checkbox',
+  'check'              => 'Rose::HTML::Form::Field::Checkbox',
+
+  'radio button'       => 'Rose::HTML::Form::Field::RadioButton',
+  'radio'              => 'Rose::HTML::Form::Field::RadioButton',
+
+  'checkboxes'         => 'Rose::HTML::Form::Field::CheckboxGroup',
+  'checks'             => 'Rose::HTML::Form::Field::CheckboxGroup',
+  'checkbox group'     => 'Rose::HTML::Form::Field::CheckboxGroup',
+  'check group'        => 'Rose::HTML::Form::Field::CheckboxGroup',
+
+  'radio buttons'      => 'Rose::HTML::Form::Field::RadioButtonGroup',
+  'radios'             => 'Rose::HTML::Form::Field::RadioButtonGroup',
+  'radio button group' => 'Rose::HTML::Form::Field::RadioButtonGroup',
+  'radio group'        => 'Rose::HTML::Form::Field::RadioButtonGroup',
+
+  'pop-up menu'        => 'Rose::HTML::Form::Field::PopUpMenu',
+  'popup menu'         => 'Rose::HTML::Form::Field::PopUpMenu',
+  'menu'               => 'Rose::HTML::Form::Field::PopUpMenu',
+
+  'select box'         => 'Rose::HTML::Form::Field::SelectBox',
+  'selectbox'          => 'Rose::HTML::Form::Field::SelectBox',
+  'select'             => 'Rose::HTML::Form::Field::SelectBox',
+
+  'submit'             => 'Rose::HTML::Form::Field::Submit',
+  'submit button'      => 'Rose::HTML::Form::Field::Submit',
+
+  'reset'              => 'Rose::HTML::Form::Field::Reset',
+  'reset button'       => 'Rose::HTML::Form::Field::Reset',
+
+  'file'               => 'Rose::HTML::Form::Field::File',
+  'upload'             => 'Rose::HTML::Form::Field::File',
+
+  'password'           => 'Rose::HTML::Form::Field::Password',
+
+  'hidden'             => 'Rose::HTML::Form::Field::Hidden',
+
+  'num'                => 'Rose::HTML::Form::Field::Numeric',
+  'number'             => 'Rose::HTML::Form::Field::Numeric',
+  'numeric'            => 'Rose::HTML::Form::Field::Numeric',
+
+  'int'                => 'Rose::HTML::Form::Field::Integer',
+  'integer'            => 'Rose::HTML::Form::Field::Integer',
+
+  'email'              => 'Rose::HTML::Form::Field::Email',
+
+  'phone'              => 'Rose::HTML::Form::Field::PhoneNumber::US',
+  'phone us'           => 'Rose::HTML::Form::Field::PhoneNumber::US',
+
+  'phone us split'     => 'Rose::HTML::Form::Field::PhoneNumber::US::Split',
+
+  'set'                => 'Rose::HTML::Form::Field::Set',
+
+  'time'               => 'Rose::HTML::Form::Field::Time',
+  'time split hms'     => 'Rose::HTML::Form::Field::Time::Split::HourMinuteSecond',
+
+  'time hours'         => 'Rose::HTML::Form::Field::Time::Hours',
+  'time minutes'       => 'Rose::HTML::Form::Field::Time::Minutes',
+  'time seconds'       => 'Rose::HTML::Form::Field::Time::Seconds',
+
+  'date'               => 'Rose::HTML::Form::Field::Date',
+  'datetime'           => 'Rose::HTML::Form::Field::DateTime',
+
+  'datetime range'     => 'Rose::HTML::Form::Field::DateTime::Range',
+
+  'datetime start'     => 'Rose::HTML::Form::Field::DateTime::StartDate',
+  'datetime end'       => 'Rose::HTML::Form::Field::DateTime::EndDate',
+
+  'datetime split mdy'    => 'Rose::HTML::Form::Field::DateTime::Split::MonthDayYear',
+  'datetime split mdyhms' => 'Rose::HTML::Form::Field::DateTime::Split::MDYHMS',
+);
+
+#
+# Object data
+#
+
 use Rose::Object::MakeMethods::Generic
 (
+  scalar =>
+  [
+    'html_element',  # may be read-only in subclasses
+    'xhtml_element', # may be read-only in subclasses
+  ],
+
   boolean =>
   [
     'escape_html'         => { default => 1 },
-    'validate_html_attrs' => { default => 1 }
+    'validate_html_attrs' => { default => 1 },
+    'is_self_closing'     => { default => 0 },
   ],
 
-  'scalar' =>
+  'scalar --get_set_init' =>
   [
     'html_error_formatter',
     'xhtml_error_formatter',
@@ -33,8 +174,6 @@ use Rose::Class::MakeMethods::Generic
 (
   inheritable_scalar =>
   [
-    'html_element',  # may be read-only in subclasses
-    'xhtml_element', # may be read-only in subclasses
     'autoload_html_attr_methods',
     'force_utf8',
   ],
@@ -68,31 +207,25 @@ use Rose::Class::MakeMethods::Set
   ]
 );
 
-__PACKAGE__->localizer(Rose::HTML::Object::Message::Localizer->new);
-
-__PACKAGE__->autoload_html_attr_methods(1);
-
-__PACKAGE__->add_valid_html_attrs
+use Rose::HTML::Object::MakeMethods::Generic
 (
-  'id',
-  'class',
-  'style',
-  'title',
-  'lang',
-  'xml:lang',
-  'dir',
-  'onclick',
-  'ondblclick',
-  'onmousedown',
-  'onmouseup',
-  'onmouseover',
-  'onmousemove',
-  'onmouseout',
-  'onkeypress',
-  'onkeydown',
-  'onkeyup'
+  array =>
+  [
+    'children'         => { interface => 'get_set_inited' },
+    'child'            => { interface => 'get_item', hash_key => 'children' },
+    'push_children'    => { interface => 'push', hash_key => 'children' },
+    'pop_children'     => { interface => 'pop', hash_key => 'children' },
+    'shift_children'   => { interface => 'shift', hash_key => 'children' },
+    'unshift_children' => { interface => 'unshift', hash_key => 'children' },
+    'delete_children'  => { interface => 'clear', hash_key => 'children' },
+    'delete_child_at_index'  => { interface => 'delete_item', hash_key => 'children' },
+  ],
 );
 
+#
+# Constructor
+#
+
 sub new
 {
   my($class) = shift;
@@ -102,7 +235,7 @@ sub new
     html_attrs  => {},
     escape_html => 1,
     error       => undef,
-    validate_html_attrs => 1,
+    validate_html_attrs => $class eq __PACKAGE__ ? 0 : 1,
   };
 
   bless $self, $class;
@@ -112,10 +245,16 @@ sub new
   return $self;
 }
 
+#
+# Object methods
+#
+
 sub init
 {
   my($self) = shift;
 
+  @_ = (element => @_)  if(@_ % 2);
+
   my $class = ref $self;
 
   no strict 'refs';
@@ -127,10 +266,99 @@ sub init
   $self->SUPER::init(@_);
 }
 
-sub children 
+sub add_children  { shift->push_children(@_) }
+sub add_child     { shift->push_children(@_) }
+sub push_child    { shift->push_children(@_) }
+sub pop_child     { shift->pop_children(@_) }
+sub shift_child   { shift->shift_children(@_) }
+sub unshift_child { shift->unshift_children(@_) }
+
+sub has_children
 {
-  croak "children() does not take any arguments"  if(@_ > 1);
-  return wantarray ? () : [];
+  my $children = shift->children; 
+  return $children && @$children ? 1 : 0;
+}
+
+sub has_parent { shift->parent ? 1 : 0 }
+
+sub parent
+{
+  my($self) = shift; 
+
+  if(@_)
+  {
+    my $old_parent = $self->parent;
+
+    Scalar::Util::weaken($self->{'parent'} = shift);
+
+    my $new_parent = $self->{'parent'};
+
+    if($old_parent && Scalar::Util::refaddr($old_parent) != Scalar::Util::refaddr($new_parent))
+    {
+      $old_parent->delete_child($self);
+      $new_parent->push_child($self)  unless($new_parent->has_child($self));
+    }
+  }
+
+  return $self->{'parent'};
+}
+
+sub descendants { map { $_, $_->descendants } shift->children }
+
+sub delete_child
+{
+  my($self) = shift;
+
+  if($_[0] =~ /^[+-]?\d+$/)
+  {
+    return $self->delete_child_at_index(@_);
+  }
+
+  my $refaddr = Scalar::Util::refaddr($_[0]);
+
+  my $i = 0;
+
+  foreach my $child ($self->children)
+  {
+    if(Scalar::Util::refaddr($child) == $refaddr)
+    {
+      return $self->delete_child_at_index($i);
+    }
+
+    $i++;
+  }
+
+  return undef;
+}
+
+sub has_child
+{
+  my($self) = shift;
+
+  my $refaddr = Scalar::Util::refaddr($_[0]);
+
+  foreach my $child ($self->children)
+  {
+    if(Scalar::Util::refaddr($child) == $refaddr)
+    {
+      return 1;
+    }
+  }
+
+  return 0;
+}
+
+sub init_html_error_formatter  { }
+sub init_xhtml_error_formatter { }
+
+sub element
+{
+  my($self) = shift;
+
+  return $self->html_element  unless(@_);
+
+  $self->xhtml_element(@_);
+  return $self->html_element(@_);
 }
 
 sub html_attr_exists
@@ -443,15 +671,33 @@ sub xhtml { shift->xhtml_tag(@_) }
 sub html_tag
 {
   my($self) = shift;
-  no warnings;
-  return '<' . ref($self)->html_element . $self->html_attrs_string . '>';
+
+  no warnings 'uninitialized';
+
+  if($self->has_children || !$self->is_self_closing)
+  {
+    return '<' . $self->html_element . $self->html_attrs_string . '>' . 
+           join('', map { $_->html_tag } $self->children) . 
+           '</' . $self->html_element . '>';
+  }
+
+  return '<' . $self->html_element . $self->html_attrs_string . '>';
 }
 
 sub xhtml_tag
 {
   my($self) = shift;
-  no warnings;
-  return '<' . ref($self)->xhtml_element . $self->xhtml_attrs_string . ' />';
+
+  no warnings 'uninitialized';
+
+  if($self->has_children || !$self->is_self_closing)
+  {
+    return '<' . $self->xhtml_element . $self->xhtml_attrs_string . '>' . 
+           join('', map { $_->xhtml_tag } $self->children) . 
+           '</' . $self->xhtml_element . '>';
+  }
+
+  return '<' . $self->xhtml_element . $self->xhtml_attrs_string . ' />';
 }
 
 #
@@ -461,33 +707,45 @@ sub xhtml_tag
 sub start_html
 {
   my($self) = shift;
-  my $html = $self->html;
-  $html =~ s{</\w+>\z}{};
-  return $html;
+
+  return '<' . $self->html_element . $self->html_attrs_string . '>';
+
+  #my $html = $self->html;
+  #$html =~ s{</\w+>\z}{};
+  #return $html;
 }
 
 sub end_html
 {
   my($self) = shift;
-  my $html = $self->html;
-  $html =~ m{</\w+>\z};
-  return $1 || '';
+
+  return '</' . $self->html_element . '>';
+
+  #my $html = $self->html;
+  #$html =~ m{</\w+>\z};
+  #return $1 || '';
 }
 
 sub start_xhtml
 {
   my($self) = shift;
-  my $xhtml = $self->xhtml;
-  $xhtml =~ s{</\w+>\z}{};
-  return $xhtml;
+
+  return '<' . $self->xhtml_element . $self->xhtml_attrs_string . '>';
+
+  #my $xhtml = $self->xhtml;
+  #$xhtml =~ s{</\w+>\z}{};
+  #return $xhtml;
 }
 
 sub end_xhtml
 {
   my($self) = shift;
-  my $xhtml = $self->xhtml;
-  $xhtml =~ m{</\w+>\z};
-  return $1 || '';
+
+  return '</' . $self->xhtml_element . '>';
+
+  #my $xhtml = $self->xhtml;
+  #$xhtml =~ m{</\w+>\z};
+  #return $1 || '';
 }
 
 sub default_html_attr_value 
@@ -648,24 +906,32 @@ sub AUTOLOAD
 {
   my($self) = $_[0];
 
-  my $class = ref($self) or croak "$self is not an object";
-
-  my $name = $AUTOLOAD;
-  $name =~ s/.*://;
-
-  if($class->html_attr_is_valid($name) && $class->autoload_html_attr_methods)
+  if(my $class = ref($self))
   {
-    no strict 'refs';
-    *$AUTOLOAD = sub { shift->html_attr($name, @_) };
-    ${$class . '::__AUTOLOADED'}{$name} = 1;
-    goto &$AUTOLOAD;
-  }
+    my $name = $AUTOLOAD;
+    $name =~ s/.*://;
 
-  confess
-    qq(Can't locate object method "$name" via package "$class" - ) .
-    ($class->html_attr_is_valid($name) ? 
-    "did not auto-create method because $class->autoload_html_attr_methods is not set" :
-    "no such method, and none auto-created because it is not a valid HTML attribute for this class");
+    if($class->html_attr_is_valid($name) && $class->autoload_html_attr_methods)
+    {
+      no strict 'refs';
+      *$AUTOLOAD = sub { shift->html_attr($name, @_) };
+      ${$class . '::__AUTOLOADED'}{$name} = 1;
+      goto &$AUTOLOAD;
+    }
+
+    confess
+      qq(Can't locate object method "$name" via package "$class" - ) .
+      ($class->html_attr_is_valid($name) ? 
+      "did not auto-create method because $class->autoload_html_attr_methods is not set" :
+      "no such method, and none auto-created because it is not a valid HTML attribute for this class");
+  }
+  else
+  {
+    my $name = $AUTOLOAD;
+    $name =~ s/.*://;
+
+    confess qq(Can't locate class method "$name" via package "$self");
+  }
 }
 
 1;
@@ -678,6 +944,48 @@ Rose::HTML::Object - HTML object base class.
 
 =head1 SYNOPSIS
 
+  #
+  # Generic HTML construction
+  #
+
+  $o = Rose::HTML::Object->new('p');
+  $o->push_child('Hi');
+
+  print $o->html; # <p>hi</p>
+
+  $br = Rose::HTML::Object->new(element => 'br', is_self_closing => 1);
+
+  print $br->html;  # <br>
+  print $br->xhtml; # <br />
+
+  $o->unshift_children($br, ' ');
+
+  print $o->html; # <p><br> Hi</p>
+
+  $b = Rose::HTML::Object->new(body => children => $o);
+
+  print $b->html; # <body><p><br> Hi</p></body>
+
+  foreach my $object ($b->descendants)
+  {
+    ...
+  }
+
+  $d = Rose::HTML::Object->new('div', class => 'x');
+
+  $b->child(0)->parent($d); # re-parent
+
+  print $b->html; # <body></body>
+  print $d->html; # <div class="x"><p><br> Hi</p></div>
+
+
+
+
+
+  #
+  # Subclass to add strictures
+  #
+
   package MyTag;
 
   use Rose::HTML::Object;
@@ -729,6 +1037,10 @@ L<Rose::HTML::Object> is the base class for HTML objects.  It defines the HTML e
 
 This class inherits from, and follows the conventions of, L<Rose::Object>. See the L<Rose::Object> documentation for more information.
 
+=head1 HIERARCHY
+
+Each L<Rose::HTML::Object> may have zero or more L<children|/children>, each of which is another L<Rose::HTML::Object> (or L<Rose::HTML::Object>-derived) object.  The L<html|/html> produced for an object will include the HTML for all of its L<descendants|/descendants>.
+
 =head1 VALIDATION
 
 Although several methods, data structures, and policies exist to aid the creation of valid HTML, they are in no way a replacement for real markup validation.
@@ -853,12 +1165,6 @@ Returns a boolean value indicating whether or not the attribute NAME is a requir
 
 Returns a boolean value indicating whether or not the attribute NAME is a valid HTML attribute.
 
-=item B<html_element [NAME]>
-
-Get or set the name of the HTML element.  The HTML element is the name of the tag, e.g. "img", "p", "a", "select", "textarea", etc.
-
-This attribute may be read-only in subclasses, but is read/write here for increased flexibility.  The value is inherited by subclasses.
-
 =item B<required_html_attrs>
 
 Returns a reference to a sorted list of required HTML attributes in scalar context, or a sorted list of required HTML attributes in list context. The default set of required HTML attributes is empty.
@@ -907,9 +1213,9 @@ This attribute may be read-only in subclasses, but is read/write here for increa
 
 =over 4
 
-=item B<new PARAMS>
+=item B<new [ PARAMS | ELEMENT, PARAMS ]>
 
-Constructs a new L<Rose::HTML::Object> object based on PARAMS, where PARAMS are name/value pairs.  Any object method is a valid parameter name.
+Constructs a new L<Rose::HTML::Object> object.  If an odd number of arguments is passed, the first argument is taken as the value for the L<element|/element> parameter.  Otherwise an even number of PARAMS name/value pairs are expected.  Any object method is a valid parameter name.
 
 =back
 
@@ -917,11 +1223,23 @@ Constructs a new L<Rose::HTML::Object> object based on PARAMS, where PARAMS are
 
 =over 4
 
-=item B<children>
+=item B<add_child OBJECT>
 
-Returns a list (in list context) or a reference to an array (in scalar context) of L<Rose::HTML::Object>-derived objects that are contained within, or otherwise "children of" this object.
+This is an alias for the L<push_child|/push_child> method.
 
-The array reference return value should be treated as read-only.  The individual items may be treated as read/write provided that you understand that you're modifying the actual children, not copies.
+=item B<add_children OBJECTS>
+
+This is an alias for the L<push_children|/push_children> method.
+
+=item B<child [INT]>
+
+Returns the L<child|/children> at the index specified by INT.  The first child is at index zero (0).
+
+=item B<children [LIST]>
+
+Get or set the list of L<Rose::HTML::Object>-derived objects that are contained within, or otherwise "children of" this object.  Any plain scalar in LIST is converted to a L<Rose::HTML::Text> object, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+
+Returns a list (in list context) or a reference to an array (in scalar context) of L<Rose::HTML::Object>-derived objects.  The array reference return value should be treated as read-only.  The individual items may be treated as read/write provided that you understand that you're modifying the actual children, not copies.
 
 =item B<clear_all_html_attrs>
 
@@ -939,6 +1257,14 @@ Clears the HTML attributes specified by NAME1, NAME2, etc. by settings their val
 
 Deletes all the HTML attributes.
 
+=item B<delete_child [ INDEX | OBJECT ]>
+
+Delete the L<child|/children> at INDEX (starting from zero) or the exact child OBJECT.
+
+=item B<delete_children>
+
+Deletes all L<children|/children>.
+
 =item B<delete_html_attr NAME>
 
 Deletes the HTML attribute NAME.
@@ -947,6 +1273,14 @@ Deletes the HTML attribute NAME.
 
 Deletes the HTML attributes specified by NAME1, NAME2, etc.
 
+=item B<descendants>
+
+Returns a list of the L<children|/children> of this object, plus all their children, and so on.
+
+=item B<element [NAME]>
+
+If passed a NAME, sets both L<html_element|/html_element> and L<xhtml_element|/xhtml_element> to NAME.  Returns L<html_element|/html_element>.
+
 =item B<error [TEXT]>
 
 Get or set an error string.
@@ -955,6 +1289,18 @@ Get or set an error string.
 
 This flag may be used by other methods to decide whether or not to escape HTML.  It is set to true by default.  The only method in L<Rose::HTML::Object> that references it is L<html_error|/html_error>.  All other HTML is escaped as appropriate regardless of the L<escape_html|/escape_html> setting (e.g. the text returned by C<html_attrs_string> always has its attribute values escaped).  Subclasses may consult this flag for similar purposes (which they must document, of course).
 
+=item B<has_child OBJECT>
+
+Returns true if OBJECT is a L<child|/children> of this object, false otherwise.
+
+=item B<has_children>
+
+Returns true if there are any L<children|/children>, false otherwise.
+
+=item B<has_parent>
+
+Returns true if this object is the L<child|/children> of another object, false otherwise.
+
 =item B<has_error>
 
 Returns true if an L<error|/error> is set, false otherwise.
@@ -1043,6 +1389,12 @@ Examples:
     $o->html_attr(color => 'red');   # color set to 'RED'
     $color = $o->html_attr('color'); # $color = 'RED'
 
+=item B<html_element [NAME]>
+
+Get or set the name of the HTML element.  The HTML element is the name of the tag, e.g. "img", "p", "a", "select", "textarea", etc.
+
+This attribute may be read-only in subclasses.
+
 =item B<html_error>
 
 Returns the error text, if any, as a snippet of HTML that looks like this:
@@ -1055,22 +1407,78 @@ If the L<escape_html|/escape_html> flag is set to true (the default), then the e
 
 Serializes the object as an HTML tag.  In other words, it is the concatenation of the strings returned by L<html_element()|/html_element> and L<html_attrs_string()|/html_attrs_string>, wrapped with the appropriate angled brackets.
 
+=item B<is_self_closing [BOOL]>
+
+Get or set a boolean attribute that determines whether or not the HTML for this object requires a separate closing tag.  If set to true, then an empty "foo" tag would looke like this:
+
+     HTML: <foo>
+    XHTML: <foo />
+
+If false, then the tags above would look like this instead:
+
+     HTML: <foo></foo>
+    XHTML: <foo></foo>
+
+The default value is false.  This attribute may be read-only in subclasses.
+
+=item B<parent [OBJECT]>
+
+Get or set the parent object.
+
+=item B<pop_child [INT]>
+
+Remove an object from the end of the list of L<children|/children> and return it.
+
+=item B<pop_children [INT]>
+
+Remove INT objects from the end of the list of L<children|/children> and return them.  If INT is ommitted, it defaults to 1.
+
+=item B<push_child OBJECT>
+
+Add OBJECT to the end of the list of L<children|/children>.  The object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  If it's a plain scalar, it will be converted to a L<Rose::HTML::Text> object, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+
+=item B<push_children OBJECTS>
+
+Add OBJECTS to the end of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+
 =item B<set_error>
 
 Set the L<error|/error> to a defined but "invisible" (zero-length) value.  This value will not be displayed by the L<html_error|/html_error> or L<xhtml_error|/xhtml_error>.  Use this method when you want to flag a field as having an error, but don't want a visible error message.
 
+=item B<shift_child [INT]>
+
+Remove an object from the start of the list of L<children|/children> and return it.
+
+=item B<shift_children [INT]>
+
+Remove INT objects from the start of the list of L<children|/children> and return them.  If INT is ommitted, it defaults to 1.
+
+=item B<unshift_child OBJECT>
+
+Add OBJECT to the start of the list of L<children|/children>.  The object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  If it's a plain scalar, it will be converted to a L<Rose::HTML::Text> object, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+
+=item B<unshift_children OBJECTS>
+
+Add OBJECTS to the start of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+
 =item B<unset_error>
 
 Set the L<error|/error> to a undef.
 
 =item B<validate_html_attrs BOOL>
 
-If set to true, HTML attribute arguments to C<html_attr> and C<html_attr_hook> will be validated by calling C<html_attr_is_valid(ATTR)>, where ATTR is the name of the attribute being set or read.  The default value is true.
+If set to true, HTML attribute arguments to C<html_attr> and C<html_attr_hook> will be validated by calling C<html_attr_is_valid(ATTR)>, where ATTR is the name of the attribute being set or read.  The default value is true for any class derived from L<Rose::HTML::Object>, but false for objects whose class is L<Rose::HTML::Object>.
 
 =item B<xhtml>
 
 A synonym for L<xhtml_tag()|/xhtml_tag>.
 
+=item B<xhtml_element [NAME]>
+
+Get or set the name of the XHTML element.  The XHTML element is the name of the tag, e.g. "img", "p", "a", "select", "textarea", etc.
+
+This attribute may be read-only in subclasses.
+
 =item B<xhtml_error>
 
 Returns the error text, if any, as a snippet of XHTML that looks like this:
