@@ -3,7 +3,7 @@ package Rose::HTML::Objects;
 use strict;
 
 # The sole purpose of this module is to provide a version number
-our $VERSION = '0.553';
+our $VERSION = '0.554';
 
 1;
 
@@ -67,7 +67,7 @@ L<http://rose.googlecode.com>
 
 =head1 CONTRIBUTORS
 
-Uwe Voelker, Jacques Supcik, Cees Hek, Denis Moskowitz 
+Uwe Voelker, Jacques Supcik, Cees Hek, Denis Moskowitz
 
 =head1 AUTHOR
 
